# ITU Prefixes

[![PyPI - Version](https://img.shields.io/pypi/v/ham-tools.svg)](https://pypi.org/project/ham-tools)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ham-tools.svg)](https://pypi.org/project/ham-tools)

-----

```console
pip install ham-tools
```


## License

`itu-prefixes` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
